@@ -1,7 +1,7 @@
 package Aniki::Schema::Relationship;
 use 5.014002;
 
-use namespace::sweep;
+use namespace::autoclean;
 use Mouse v2.4.5;
 use Aniki::Schema::Relationship::Fetcher;
 use Lingua::EN::Inflect qw/PL/;
